@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-29 09:40:42
-@LastEditTime: 2021-04-27 11:43:51
+@LastEditTime: 2021-05-28 16:21:09
 @LastEditors: HuangJianYi
 :description: 机台（盒子）
 """
@@ -12,6 +12,7 @@ from seven_cloudapp.models.enum import OperationType
 from seven_cloudapp.models.seven_model import PageInfo
 from seven_cloudapp.models.behavior_model import *
 from seven_cloudapp.models.db_models.machine.machine_value_model import *
+from seven_cloudapp.models.db_models.price.price_gear_model import *
 
 from seven_cloudapp.handlers.server.machine_s import MachineReleaseHandler
 from seven_cloudapp.handlers.server.machine_s import CheckBuyEndboxHandler
@@ -207,4 +208,34 @@ class MachineDelHandler(SevenBaseHandler):
 
         self.create_operation_log(OperationType.delete.value, "machine_info_tb", "MachineDelHandler", None, machine_id)
 
+        return self.reponse_json_success()
+
+
+class UpdateMachinePriceByGearIdHandler(SevenBaseHandler):
+    """
+    :description: 更新机台价格，通过档位id
+    """
+    @filter_check_params("machine_id")
+    def get_async(self):
+        """
+        :description: 更新机台价格，通过档位id
+        :param act_id：活动id
+        :param gear_id：档位id
+        :return: reponse_json_success
+        :last_editors: HuangJingCan
+        """
+        act_id = int(self.get_param("act_id", 0))
+        gear_id = int(self.get_param("gear_id", 0))
+
+        if act_id <= 0 or gear_id <= 0:
+            return self.reponse_json_error_params()
+
+        price_gear_model = PriceGearModel(context=self)
+        price_gear = price_gear_model.get_dict_by_id(gear_id)
+        if not price_gear or price_gear["act_id"]!= act_id:
+            return self.reponse_json_error("Error","价格档位不存在")
+
+        machine_info_model = MachineInfoModel(context=self)
+        machine_info_model.update_table("machine_price=%s", "act_id=%s and price_gears_id=%s", params=[price_gear["price"], act_id,gear_id])
+
         return self.reponse_json_success()
\ No newline at end of file
