@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-16 14:38:22
-:LastEditTime: 2021-04-15 17:22:21
-:LastEditors: HuangJingCan
+@LastEditTime: 2021-05-28 16:23:32
+@LastEditors: HuangJianYi
 :Description: 潮玩盲盒基础路由
 """
 # 框架引用
@@ -54,6 +54,7 @@ def seven_cloudapp_ppmt_route():
         (r"/server/machine_del", machine_s.MachineDelHandler),
         (r"/server/machine_list", machine_s.MachineListHandler),
         (r"/server/machine_release", machine_s.MachineReleaseHandler),
+        (r"/server/update_machineprice_by_gearid", machine_s.UpdateMachinePriceByGearIdHandler),
         (r"/server/goods_list", goods_s.GoodsListHandler),
         (r"/server/goods_info", goods_s.GoodsInfoHandler),
         (r"/server/goods_check", goods_s.GoodsCheckHandler),
